@@ -1,4 +1,4 @@
-// Copyright (C) 2011-2015 National ICT Australia (NICTA)
+// Copyright (C) 2011-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -137,6 +137,34 @@ arrayops::fill_zeros(eT* dest, const uword n_elem)
 
 
 
+template<typename eT>
+arma_hot
+inline
+void
+arrayops::replace(eT* mem, const uword n_elem, const eT old_val, const eT new_val)
+  {
+  if(arma_isnan(old_val))
+    {
+    for(uword i=0; i<n_elem; ++i)
+      {
+      eT& val = mem[i];
+      
+      val = (arma_isnan(val)) ? new_val : val;
+      }
+    }
+  else
+    {
+    for(uword i=0; i<n_elem; ++i)
+      {
+      eT& val = mem[i];
+      
+      val = (val == old_val) ? new_val : val;
+      }
+    }
+  }
+
+
+
 template<typename out_eT, typename in_eT>
 arma_hot
 arma_inline
@@ -889,7 +917,6 @@ arrayops::inplace_div_base(eT* dest, const eT val, const uword n_elem)
 
 template<typename eT>
 arma_hot
-arma_pure
 inline
 eT
 arrayops::accumulate(const eT* src, const uword n_elem)
@@ -937,7 +964,6 @@ arrayops::accumulate(const eT* src, const uword n_elem)
 
 template<typename eT>
 arma_hot
-arma_pure
 inline
 eT
 arrayops::product(const eT* src, const uword n_elem)
@@ -965,7 +991,6 @@ arrayops::product(const eT* src, const uword n_elem)
 
 template<typename eT>
 arma_hot
-arma_pure
 inline
 bool
 arrayops::is_finite(const eT* src, const uword n_elem)
@@ -998,7 +1023,6 @@ arrayops::is_finite(const eT* src, const uword n_elem)
 
 template<typename eT>
 arma_hot
-arma_pure
 inline
 bool
 arrayops::has_inf(const eT* src, const uword n_elem)
@@ -1025,7 +1049,6 @@ arrayops::has_inf(const eT* src, const uword n_elem)
 
 template<typename eT>
 arma_hot
-arma_pure
 inline
 bool
 arrayops::has_nan(const eT* src, const uword n_elem)
