@@ -1,4 +1,4 @@
-// Copyright (C) 2008-2015 National ICT Australia (NICTA)
+// Copyright (C) 2008-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -16,6 +16,7 @@
 // real
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< (is_arma_type<T1>::value && is_cx<typename T1::elem_type>::no), const T1& >::result
 real(const T1& X)
@@ -28,6 +29,7 @@ real(const T1& X)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const T1&
 real(const BaseCube<typename T1::pod_type, T1>& X)
@@ -40,6 +42,7 @@ real(const BaseCube<typename T1::pod_type, T1>& X)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const T1&
 real(const SpBase<typename T1::pod_type,T1>& A)
@@ -52,6 +55,7 @@ real(const SpBase<typename T1::pod_type,T1>& A)
 
 
 template<typename T1>
+arma_warn_unused
 inline
 typename enable_if2< (is_arma_type<T1>::value && is_cx<typename T1::elem_type>::yes), const mtOp<typename T1::pod_type, T1, op_real> >::result
 real(const T1& X)
@@ -64,6 +68,7 @@ real(const T1& X)
 
 
 template<typename T1>
+arma_warn_unused
 inline
 const mtOpCube<typename T1::pod_type, T1, op_real>
 real(const BaseCube<std::complex<typename T1::pod_type>, T1>& X)
@@ -76,6 +81,7 @@ real(const BaseCube<std::complex<typename T1::pod_type>, T1>& X)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const mtSpOp<typename T1::pod_type, T1, spop_real>
 real(const SpBase<std::complex<typename T1::pod_type>,T1>& A)
@@ -91,6 +97,7 @@ real(const SpBase<std::complex<typename T1::pod_type>,T1>& A)
 // imag
 
 template<typename T1>
+arma_warn_unused
 inline
 const Gen< Mat<typename T1::pod_type>, gen_zeros >
 imag(const Base<typename T1::pod_type,T1>& X)
@@ -105,6 +112,7 @@ imag(const Base<typename T1::pod_type,T1>& X)
 
 
 template<typename T1>
+arma_warn_unused
 inline
 const GenCube<typename T1::pod_type, gen_zeros>
 imag(const BaseCube<typename T1::pod_type,T1>& X)
@@ -119,6 +127,7 @@ imag(const BaseCube<typename T1::pod_type,T1>& X)
 
 
 template<typename T1>
+arma_warn_unused
 inline
 SpMat<typename T1::pod_type>
 imag(const SpBase<typename T1::pod_type,T1>& A)
@@ -133,6 +142,7 @@ imag(const SpBase<typename T1::pod_type,T1>& A)
 
 
 template<typename T1>
+arma_warn_unused
 inline
 typename enable_if2< (is_arma_type<T1>::value && is_cx<typename T1::elem_type>::yes), const mtOp<typename T1::pod_type, T1, op_imag> >::result
 imag(const T1& X)
@@ -145,6 +155,7 @@ imag(const T1& X)
 
 
 template<typename T1>
+arma_warn_unused
 inline
 const mtOpCube<typename T1::pod_type, T1, op_imag>
 imag(const BaseCube<std::complex<typename T1::pod_type>,T1>& X)
@@ -157,6 +168,7 @@ imag(const BaseCube<std::complex<typename T1::pod_type>,T1>& X)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const mtSpOp<typename T1::pod_type, T1, spop_imag>
 imag(const SpBase<std::complex<typename T1::pod_type>,T1>& A)
@@ -172,6 +184,7 @@ imag(const SpBase<std::complex<typename T1::pod_type>,T1>& A)
 // log
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_log> >::result
 log(const T1& A)
@@ -184,6 +197,7 @@ log(const T1& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_log>
 log(const BaseCube<typename T1::elem_type,T1>& A)
@@ -199,6 +213,7 @@ log(const BaseCube<typename T1::elem_type,T1>& A)
 // log2
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_log2> >::result
 log2(const T1& A)
@@ -211,6 +226,7 @@ log2(const T1& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_log2>
 log2(const BaseCube<typename T1::elem_type,T1>& A)
@@ -226,6 +242,7 @@ log2(const BaseCube<typename T1::elem_type,T1>& A)
 // log10
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_log10> >::result
 log10(const T1& A)
@@ -238,6 +255,7 @@ log10(const T1& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_log10>
 log10(const BaseCube<typename T1::elem_type,T1>& A)
@@ -253,6 +271,7 @@ log10(const BaseCube<typename T1::elem_type,T1>& A)
 // exp
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_exp> >::result
 exp(const T1& A)
@@ -265,6 +284,7 @@ exp(const T1& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_exp>
 exp(const BaseCube<typename T1::elem_type,T1>& A)
@@ -279,6 +299,7 @@ exp(const BaseCube<typename T1::elem_type,T1>& A)
 // exp2
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_exp2> >::result
 exp2(const T1& A)
@@ -291,6 +312,7 @@ exp2(const T1& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_exp2>
 exp2(const BaseCube<typename T1::elem_type,T1>& A)
@@ -305,6 +327,7 @@ exp2(const BaseCube<typename T1::elem_type,T1>& A)
 // exp10
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_exp10> >::result
 exp10(const T1& A)
@@ -317,6 +340,7 @@ exp10(const T1& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_exp10>
 exp10(const BaseCube<typename T1::elem_type,T1>& A)
@@ -333,6 +357,7 @@ exp10(const BaseCube<typename T1::elem_type,T1>& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< (is_arma_type<T1>::value && is_cx<typename T1::elem_type>::no), const eOp<T1, eop_abs> >::result
 abs(const T1& X)
@@ -345,6 +370,7 @@ abs(const T1& X)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_abs>
 abs(const BaseCube<typename T1::elem_type,T1>& X, const typename arma_not_cx<typename T1::elem_type>::result* junk = 0)
@@ -359,6 +385,7 @@ abs(const BaseCube<typename T1::elem_type,T1>& X, const typename arma_not_cx<typ
 
 
 template<typename T1>
+arma_warn_unused
 inline
 typename enable_if2< (is_arma_type<T1>::value && is_cx<typename T1::elem_type>::yes), const mtOp<typename T1::pod_type, T1, op_abs> >::result
 abs(const T1& X)
@@ -371,6 +398,7 @@ abs(const T1& X)
 
 
 template<typename T1>
+arma_warn_unused
 inline
 const mtOpCube<typename T1::pod_type, T1, op_abs>
 abs(const BaseCube< std::complex<typename T1::pod_type>,T1>& X, const typename arma_cx_only<typename T1::elem_type>::result* junk = 0)
@@ -385,6 +413,7 @@ abs(const BaseCube< std::complex<typename T1::pod_type>,T1>& X, const typename a
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const SpOp<T1, spop_abs>
 abs(const SpBase<typename T1::elem_type,T1>& X, const typename arma_not_cx<typename T1::elem_type>::result* junk = 0)
@@ -398,6 +427,7 @@ abs(const SpBase<typename T1::elem_type,T1>& X, const typename arma_not_cx<typen
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const mtSpOp<typename T1::pod_type, T1, spop_cx_abs>
 abs(const SpBase< std::complex<typename T1::pod_type>, T1>& X, const typename arma_cx_only<typename T1::elem_type>::result* junk = 0)
@@ -414,6 +444,7 @@ abs(const SpBase< std::complex<typename T1::pod_type>, T1>& X, const typename ar
 // square
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_square> >::result
 square(const T1& A)
@@ -426,6 +457,7 @@ square(const T1& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_square>
 square(const BaseCube<typename T1::elem_type,T1>& A)
@@ -438,6 +470,7 @@ square(const BaseCube<typename T1::elem_type,T1>& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const SpOp<T1, spop_square>
 square(const SpBase<typename T1::elem_type,T1>& A)
@@ -453,6 +486,7 @@ square(const SpBase<typename T1::elem_type,T1>& A)
 // sqrt
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_sqrt> >::result
 sqrt(const T1& A)
@@ -465,6 +499,7 @@ sqrt(const T1& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_sqrt>
 sqrt(const BaseCube<typename T1::elem_type,T1>& A)
@@ -477,6 +512,7 @@ sqrt(const BaseCube<typename T1::elem_type,T1>& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const SpOp<T1, spop_sqrt>
 sqrt(const SpBase<typename T1::elem_type,T1>& A)
@@ -492,6 +528,7 @@ sqrt(const SpBase<typename T1::elem_type,T1>& A)
 // conj
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const T1&
 conj(const Base<typename T1::pod_type,T1>& A)
@@ -504,6 +541,7 @@ conj(const Base<typename T1::pod_type,T1>& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const T1&
 conj(const BaseCube<typename T1::pod_type,T1>& A)
@@ -516,6 +554,7 @@ conj(const BaseCube<typename T1::pod_type,T1>& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const T1&
 conj(const SpBase<typename T1::pod_type,T1>& A)
@@ -528,6 +567,7 @@ conj(const SpBase<typename T1::pod_type,T1>& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOp<T1, eop_conj>
 conj(const Base<std::complex<typename T1::pod_type>,T1>& A)
@@ -540,6 +580,7 @@ conj(const Base<std::complex<typename T1::pod_type>,T1>& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_conj>
 conj(const BaseCube<std::complex<typename T1::pod_type>,T1>& A)
@@ -552,6 +593,7 @@ conj(const BaseCube<std::complex<typename T1::pod_type>,T1>& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const SpOp<T1, spop_conj>
 conj(const SpBase<std::complex<typename T1::pod_type>,T1>& A)
@@ -566,6 +608,7 @@ conj(const SpBase<std::complex<typename T1::pod_type>,T1>& A)
 // pow
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOp<T1, eop_pow>
 pow(const Base<typename T1::elem_type,T1>& A, const typename T1::elem_type exponent)
@@ -578,6 +621,7 @@ pow(const Base<typename T1::elem_type,T1>& A, const typename T1::elem_type expon
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_pow>
 pow(const BaseCube<typename T1::elem_type,T1>& A, const typename T1::elem_type exponent)
@@ -592,6 +636,7 @@ pow(const BaseCube<typename T1::elem_type,T1>& A, const typename T1::elem_type e
 // pow, specialised handling (non-complex exponent for complex matrices)
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOp<T1, eop_pow>
 pow(const Base<typename T1::elem_type,T1>& A, const typename T1::elem_type::value_type exponent)
@@ -606,6 +651,7 @@ pow(const Base<typename T1::elem_type,T1>& A, const typename T1::elem_type::valu
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_pow>
 pow(const BaseCube<typename T1::elem_type,T1>& A, const typename T1::elem_type::value_type exponent)
@@ -623,6 +669,7 @@ pow(const BaseCube<typename T1::elem_type,T1>& A, const typename T1::elem_type::
 // floor
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_floor> >::result
 floor(const T1& A)
@@ -635,6 +682,7 @@ floor(const T1& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_floor>
 floor(const BaseCube<typename T1::elem_type,T1>& A)
@@ -650,6 +698,7 @@ floor(const BaseCube<typename T1::elem_type,T1>& A)
 // ceil
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_ceil> >::result
 ceil(const T1& A)
@@ -662,6 +711,7 @@ ceil(const T1& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_ceil>
 ceil(const BaseCube<typename T1::elem_type,T1>& A)
@@ -677,6 +727,7 @@ ceil(const BaseCube<typename T1::elem_type,T1>& A)
 // round
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_round> >::result
 round(const T1& A)
@@ -689,6 +740,7 @@ round(const T1& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_round>
 round(const BaseCube<typename T1::elem_type,T1>& A)
@@ -700,10 +752,40 @@ round(const BaseCube<typename T1::elem_type,T1>& A)
 
 
 
+//
+// trunc
+
+template<typename T1>
+arma_warn_unused
+arma_inline
+typename enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_trunc> >::result
+trunc(const T1& A)
+  {
+  arma_extra_debug_sigprint();
+  
+  return eOp<T1, eop_trunc>(A);
+  }
+
+
+
+template<typename T1>
+arma_warn_unused
+arma_inline
+const eOpCube<T1, eop_trunc>
+trunc(const BaseCube<typename T1::elem_type,T1>& A)
+  {
+  arma_extra_debug_sigprint();
+  
+  return eOpCube<T1, eop_trunc>(A.get_ref());
+  }
+
+
+
 //
 // sign
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_sign> >::result
 sign(const T1& A)
@@ -716,6 +798,7 @@ sign(const T1& A)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const eOpCube<T1, eop_sign>
 sign(const BaseCube<typename T1::elem_type,T1>& A)
@@ -727,4 +810,91 @@ sign(const BaseCube<typename T1::elem_type,T1>& A)
 
 
 
+//
+// erf
+
+template<typename T1>
+arma_warn_unused
+arma_inline
+typename enable_if2< (is_arma_type<T1>::value && is_cx<typename T1::elem_type>::no), const eOp<T1, eop_erf> >::result
+erf(const T1& A)
+  {
+  arma_extra_debug_sigprint();
+  
+  return eOp<T1, eop_erf>(A);
+  }
+
+
+
+template<typename T1>
+arma_warn_unused
+arma_inline
+typename enable_if2< is_cx<typename T1::elem_type>::no, const eOpCube<T1, eop_erf> >::result
+erf(const BaseCube<typename T1::elem_type,T1>& A)
+  {
+  arma_extra_debug_sigprint();
+  
+  return eOpCube<T1, eop_erf>(A.get_ref());
+  }
+
+
+
+//
+// erfc
+
+template<typename T1>
+arma_warn_unused
+arma_inline
+typename enable_if2< (is_arma_type<T1>::value && is_cx<typename T1::elem_type>::no), const eOp<T1, eop_erfc> >::result
+erfc(const T1& A)
+  {
+  arma_extra_debug_sigprint();
+  
+  return eOp<T1, eop_erfc>(A);
+  }
+
+
+
+template<typename T1>
+arma_warn_unused
+arma_inline
+typename enable_if2< is_cx<typename T1::elem_type>::no, const eOpCube<T1, eop_erfc> >::result
+erfc(const BaseCube<typename T1::elem_type,T1>& A)
+  {
+  arma_extra_debug_sigprint();
+  
+  return eOpCube<T1, eop_erfc>(A.get_ref());
+  }
+
+
+
+//
+// lgamma
+
+template<typename T1>
+arma_warn_unused
+arma_inline
+typename enable_if2< (is_arma_type<T1>::value && is_cx<typename T1::elem_type>::no), const eOp<T1, eop_lgamma> >::result
+lgamma(const T1& A)
+  {
+  arma_extra_debug_sigprint();
+  
+  return eOp<T1, eop_lgamma>(A);
+  }
+
+
+
+template<typename T1>
+arma_warn_unused
+arma_inline
+typename enable_if2< is_cx<typename T1::elem_type>::no, const eOpCube<T1, eop_lgamma> >::result
+lgamma(const BaseCube<typename T1::elem_type,T1>& A)
+  {
+  arma_extra_debug_sigprint();
+  
+  return eOpCube<T1, eop_lgamma>(A.get_ref());
+  }
+
+
+
 //! @}
