@@ -46,7 +46,14 @@ sqrtmat(Mat< std::complex<typename T1::elem_type> >& Y, const Base<typename T1::
   {
   arma_extra_debug_sigprint();
   
-  return op_sqrtmat::apply_direct(Y, X.get_ref());
+  const bool status = op_sqrtmat::apply_direct(Y, X.get_ref());
+  
+  if(status == false)
+    {
+    arma_debug_warn("sqrtmat(): given matrix seems singular; may not have a square root");
+    }
+  
+  return status;
   }
 
 
@@ -58,7 +65,51 @@ sqrtmat(Mat<typename T1::elem_type>& Y, const Base<typename T1::elem_type,T1>& X
   {
   arma_extra_debug_sigprint();
   
-  return op_sqrtmat_cx::apply_direct(Y, X.get_ref());
+  const bool status = op_sqrtmat_cx::apply_direct(Y, X.get_ref());
+  
+  if(status == false)
+    {
+    arma_debug_warn("sqrtmat(): given matrix seems singular; may not have a square root");
+    }
+  
+  return status;
+  }
+
+
+
+//
+
+
+
+template<typename T1>
+arma_warn_unused
+arma_inline
+typename enable_if2< is_supported_blas_type<typename T1::elem_type>::value, const Op<T1, op_sqrtmat_sympd> >::result
+sqrtmat_sympd(const Base<typename T1::elem_type,T1>& X)
+  {
+  arma_extra_debug_sigprint();
+  
+  return Op<T1, op_sqrtmat_sympd>(X.get_ref());
+  }
+
+
+
+template<typename T1>
+inline
+typename enable_if2< is_supported_blas_type<typename T1::elem_type>::value, bool >::result
+sqrtmat_sympd(Mat<typename T1::elem_type>& Y, const Base<typename T1::elem_type,T1>& X)
+  {
+  arma_extra_debug_sigprint();
+  
+  const bool status = op_sqrtmat_sympd::apply_direct(Y, X.get_ref());
+  
+  if(status == false)
+    {
+    Y.reset();
+    arma_debug_warn("sqrtmat_sympd(): transformation failed");
+    }
+  
+  return status;
   }
 
 
