@@ -97,7 +97,7 @@ glue_times_redirect2_helper<true>::apply(Mat<typename T1::elem_type>& out, const
     if(status == false)
       {
       out.reset();
-      arma_bad("matrix multiplication: inverse of singular matrix; suggest to use solve() instead");
+      arma_stop_runtime_error("matrix multiplication: inverse of singular matrix; suggest to use solve() instead");
       }
     
     return;
@@ -216,7 +216,7 @@ glue_times_redirect3_helper<true>::apply(Mat<typename T1::elem_type>& out, const
     if(status == false)
       {
       out.reset();
-      arma_bad("matrix multiplication: inverse of singular matrix; suggest to use solve() instead");
+      arma_stop_runtime_error("matrix multiplication: inverse of singular matrix; suggest to use solve() instead");
       }
     
     return;
@@ -247,7 +247,7 @@ glue_times_redirect3_helper<true>::apply(Mat<typename T1::elem_type>& out, const
     if(status == false)
       {
       out.reset();
-      arma_bad("matrix multiplication: inverse of singular matrix; suggest to use solve() instead");
+      arma_stop_runtime_error("matrix multiplication: inverse of singular matrix; suggest to use solve() instead");
       return;
       }
     
@@ -430,7 +430,7 @@ glue_times::apply(Mat<typename T1::elem_type>& out, const Glue<T1,T2,glue_times>
   
   const sword N_mat = 1 + depth_lhs< glue_times, Glue<T1,T2,glue_times> >::num;
   
-  arma_extra_debug_print(arma_boost::format("N_mat = %d") % N_mat);
+  arma_extra_debug_print(arma_str::format("N_mat = %d") % N_mat);
   
   glue_times_redirect<N_mat>::apply(out, X);
   }
